@@ -16,9 +16,10 @@ __all__ = [
 ]
 
 import numpy as np
-from .ergodic import steady_state, fmpt
+from .ergodic import steady_state, mfpt
 from .util import fill_empty_diagonals
 from .components import Graph
+from warnings import warn
 from scipy import stats
 from scipy.stats import rankdata
 from operator import gt
@@ -80,6 +81,7 @@ class Markov(object):
     summary      : bool
                    If True, print out the summary of the Markov Chain during
                    initialization. Default is True.
+
     Attributes
     ----------
     k            : int
@@ -132,6 +134,7 @@ class Markov(object):
     array([0.30769231, 0.28846154, 0.40384615])
 
     Reducible Markov chain
+
     >>> c = [['b','a','a'],['c','c','a'],['c','b','c']]
     >>> m = Markov(c)
     The Markov Chain is reducible and is composed by:
@@ -280,10 +283,17 @@ class Markov(object):
                 print(*self.astates_indices, sep=", ")
 
     @property
-    def fmpt(self):
-        if not hasattr(self, "_fmpt"):
-            self._fmpt = fmpt(self.p, fill_empty_classes=True)
-        return self._fmpt
+    def mfpt(self):
+        warn('self._mfpt is deprecated. Please use self._mfpt')
+        if not hasattr(self, "_mfpt"):
+            self._mfpt = mfpt(self.p, fill_empty_classes=True)
+        return self._mfpt
+
+    @property
+    def mfpt(self):
+        if not hasattr(self, "_mfpt"):
+            self._mfpt = mfpt(self.p, fill_empty_classes=True)
+        return self._mfpt
 
     @property
     def steady_state(self):
@@ -623,7 +633,7 @@ class Spatial_Markov(object):
      [0.         0.01171875 0.08203125 0.87109375 0.03515625]
      [0.         0.         0.         0.03434343 0.96565657]]
 
-    We now obtain 4 5*5 spatial lag conditioned transition probability
+    We now obtain 4 (5,5) spatial lag conditioned transition probability
     matrices instead of 5 as in case (1).
 
     The Q and likelihood ratio statistics are still both significant.
@@ -643,11 +653,16 @@ class Spatial_Markov(object):
     spatial lags manually.
     For example, we want the defining cutoffs to be [0.8, 0.9, 1, 1.2],
     meaning that relative incomes:
-    2.1 smaller than 0.8 : class 0
-    2.2 between 0.8 and 0.9: class 1
-    2.3 between 0.9 and 1.0 : class 2
-    2.4 between 1.0 and 1.2: class 3
-    2.5 larger than 1.2: class 4
+
+    * class 0: smaller than 0.8
+
+    * class 1: between 0.8 and 0.9
+
+    * class 2: between 0.9 and 1.0
+
+    * class 3: between 1.0 and 1.2
+
+    * class 4: larger than 1.2
 
     >>> cc = np.array([0.8, 0.9, 1, 1.2])
     >>> sm = Spatial_Markov(rpci, w, cutoffs=cc, lag_cutoffs=cc, variable_name='rpci')
@@ -688,10 +703,11 @@ class Spatial_Markov(object):
      [0.         0.         0.         0.03932584 0.96067416]]
 
     (3.1) As we can see from the above estimated conditional transition
-    probability matrix, some rows are full of zeros which violate the
-    requirement of a transition probability matrix that every row sums to 1.
-    We can easily adjust this assigning fill_empty_classes = True when initializing
-    Spatial_Markov.
+    probability matrices, some rows are full of zeros and this violate the
+    requirement that each row of a transition probability matrix sums to 1.
+    We can easily adjust this assigning `fill_empty_classes = True` when initializing
+    `Spatial_Markov`.
+
     >>> sm = Spatial_Markov(rpci, w, cutoffs=cc, lag_cutoffs=cc, fill_empty_classes=True)
     >>> for p in sm.P:
     ...     print(p)
@@ -726,11 +742,11 @@ class Spatial_Markov(object):
     >>> sm.S[2]
     array([0.03607655, 0.22667277, 0.25883041, 0.43607249, 0.04234777])
 
-    (4) Spatial_Markov also accept discrete time series and calculate
+    (4) `Spatial_Markov` also accepts discrete time series and calculates
     categorical spatial lags on which several transition probability matrices
     are conditioned.
     Let's still use the US state income time series to demonstrate. We first
-    discretize them into categories and then pass them to Spatial_Markov.
+    discretize them into categories and then pass them to `Spatial_Markov`.
 
     >>> import mapclassify as mc
     >>> y = mc.Quantiles(rpci.flatten(), k=5).yb.reshape(rpci.shape)
@@ -851,7 +867,7 @@ class Spatial_Markov(object):
     @property
     def f(self):
         if not hasattr(self, "_f"):
-            self._f = fmpt(self.p)
+            self._f = mfpt(self.p)
         return self._f
 
     @property
@@ -859,7 +875,7 @@ class Spatial_Markov(object):
         if not hasattr(self, "_F"):
             F = np.zeros_like(self.P)
             for i, p in enumerate(self.P):
-                F[i] = fmpt(np.asarray(p))
+                F[i] = mfpt(np.asarray(p))
             self._F = np.asarray(F)
         return self._F
 
@@ -1036,9 +1052,7 @@ class Spatial_Markov(object):
             ht.summary(title=title)
 
     def _maybe_classify(self, y, k, cutoffs):
-        """Helper method for classifying continuous data.
-
-        """
+        """Helper method for classifying continuous data."""
 
         rows, cols = y.shape
         if cutoffs is None:
@@ -1979,8 +1993,8 @@ class FullRank_Markov(Markov):
                    (n, ), ergodic distribution.
     transitions  : array
                    (n, n), count of transitions between each rank i and j
-    fmpt         : array
-                   (n, n), first mean passage times.
+    mfpt         : array
+                   (n, n), mean first passage times.
     sojourn_time : array
                    (n, ), sojourn times.
 
@@ -2016,7 +2030,7 @@ class FullRank_Markov(Markov):
            [ 0.,  0.,  0., ...,  2.,  1., 77.]])
     >>> m.p[0, :5]
     array([0.825 , 0.0625, 0.0625, 0.025 , 0.025 ])
-    >>> m.fmpt[0, :5]
+    >>> m.mfpt[0, :5]
     array([48.        , 87.96280048, 68.1089084 , 58.83306575, 41.77250827])
     >>> m.sojourn_time[:5]
     array([5.71428571, 2.75862069, 2.22222222, 1.77777778, 1.66666667])
@@ -2128,8 +2142,8 @@ class GeoRank_Markov(Markov):
     transitions  : array
                    (n, n), count of rank transitions between each
                    geographic unit i and j.
-    fmpt         : array
-                   (n, n), first mean passage times.
+    mfpt         : array
+                   (n, n), mean first passage times.
     sojourn_time : array
                    (n, ), sojourn times.
 
@@ -2171,7 +2185,7 @@ class GeoRank_Markov(Markov):
            [0.025 , 0.    , 0.0625, ..., 0.425 , 0.    , 0.    ],
            [0.    , 0.    , 0.    , ..., 0.    , 0.225 , 0.025 ],
            [0.    , 0.    , 0.    , ..., 0.    , 0.0375, 0.175 ]])
-    >>> m.fmpt
+    >>> m.mfpt
     array([[ 48.        ,  63.35532038,  92.75274652, ...,  82.47515731,
              71.01114491,  68.65737127],
            [108.25928005,  48.        , 127.99032986, ...,  92.03098299,
